History
=======

0.0.1 (2021-05-12)
------------------

* Added Event Handler
* Added Command Handler
* Added Event Recurring Service
* Added Command Recurring Service
* Added Event Broker with Recurrent Service
* Added Command Broker with Recurrent Service
* Added REST Service with Health handler

0.0.2 (2021-05-17)
------------------

* Completed the Poetry Support
* added actions for documentation

0.0.3 (2021-05-24)
------------------

* renamed classes and removed Minos prefix
* Integration of Command and CommandReply with Handler

